package com.ruoyi.ibs.grid.service;

import java.util.List;
import com.ruoyi.ibs.grid.domain.entity.GridShapeCountGongsi;
import com.ruoyi.ibs.grid.domain.entity.GridShapeCountLingshou;
import com.ruoyi.ibs.grid.domain.entity.GridShapeCustGongsi;
import com.ruoyi.ibs.grid.domain.entity.GridShapeCustLingshou;
import com.ruoyi.ibs.grid.domain.entity.GridVirtualCustGongsi;
import com.ruoyi.ibs.grid.domain.entity.GridVirtualCustLingshou;
import org.springframework.stereotype.Service;

/**
 * 自定义地图网格汇总统计_公司Service接口
 *
 * @author ruoyi
 * @date 2025-05-08
 */
@Service
public interface IGridShapeCountService
{
    /**
     * 查询自定义地图网格汇总统计_公司
     *
     * @param dt 自定义地图网格汇总统计_公司主键
     * @return 自定义地图网格汇总统计_公司
     */
    public GridShapeCountGongsi selectGridShapeCountGongsiByDt(String dt);

    /**
     * 查询自定义地图网格汇总统计_公司列表
     *
     * @return 自定义地图网格汇总统计_公司集合
     */
    public List<GridShapeCountGongsi> selectGridShapeCountGongsiList(String shapeType ,String shapeName, String gridName,String dt);

    public List<GridShapeCountLingshou> selectGridShapeCountLingshouList(String shapeType , String shapeName, String gridName,String dt);

    public List<GridShapeCustGongsi> selectGridShapeCountgsCustList(String gridId , String custName, String custIdc,String dt);

    public List<GridShapeCustLingshou> selectGridShapeCountlsCustList(String gridId , String custName, String custIdc,String dt);
    /**
     * 新增自定义地图网格汇总统计_公司
     *
     * @param gridShapeCount 自定义地图网格汇总统计_公司
     * @return 结果
     */
    public int insertGridShapeCountGongsi(GridShapeCountGongsi gridShapeCount);

    /**
     * 修改自定义地图网格汇总统计_公司
     *
     * @param gridShapeCount 自定义地图网格汇总统计_公司
     * @return 结果
     */
    public int updateGridShapeCountGongsi(GridShapeCountGongsi gridShapeCount);

    /**
     * 批量删除自定义地图网格汇总统计_公司
     *
     * @param dts 需要删除的自定义地图网格汇总统计_公司主键集合
     * @return 结果
     */
    public int deleteGridShapeCountGongsiByDts(String[] dts);

    /**
     * 删除自定义地图网格汇总统计_公司信息
     *
     * @param dt 自定义地图网格汇总统计_公司主键
     * @return 结果
     */
    public int deleteGridShapeCountGongsiByDt(String dt);
}
